@@ -1,5 +1,8 @@
 package Catalyst::Controller::Validation::DFV;
-$Catalyst::Controller::Validation::DFV::VERSION = '0.0.9';
+
+our $VERSION = '0.0.11';
+$VERSION = eval $VERSION;
+
 use strict;
 use warnings;
 
@@ -24,7 +27,13 @@ sub form_check :Private {
 }
 
 
+=head1 Methods
 
+=cut
+
+=head2 add_form_invalid
+
+=cut
 sub add_form_invalid :Private {
     my ($self, $c, $invalid_key, $invalid_value) = @_;
 
@@ -43,10 +52,16 @@ sub add_form_invalid :Private {
     return;
 }
 
+=head2 validation_errors_to_html
+
+=cut
 sub validation_errors_to_html :Private {
     my ($self, $c) = @_;
 }
 
+=head2 refill_form
+
+=cut
 # factored out of a block of code I regularly paste into Controller/Root.pm
 sub refill_form :Private {
     my ($self, $c) = @_;
@@ -78,18 +93,13 @@ sub refill_form :Private {
 
 1;
 # ABSTRACT: Form validation and refilling
+__END__
 
 =pod
 
-=encoding UTF-8
+=head1 DESCRIPTION
 
-=head1 NAME
-
-Catalyst::Controller::Validation::DFV - Form validation and refilling
-
-=head1 VERSION
-
-version 0.0.9
+Form-validation using a Catalyst controller and Data::FormValidator
 
 =head1 SYNOPSIS
 
@@ -149,47 +159,22 @@ version 0.0.9
         $c->forward('refill_form');
     }
 
-=head1 DESCRIPTION
-
-Form-validation using a Catalyst controller and Data::FormValidator
-
-=head1 Methods
-
-=head2 add_form_invalid
-
-=head2 validation_errors_to_html
-
-=head2 refill_form
-
 =head1 EXAMPLES
 
 There are L<Template::Toolkit> file examples in the examples/ directory of
 this distribution.
 
-=begin markdown
-
-## BUILD STATUS
-
-### master
-
-[![Build status](https://badge.buildkite.com/a51523ccfc452014358d9666ac0a51ca30bc409da860c34b7d.svg)](https://buildkite.com/chizography/catalyst-validation-dfv)
-
-=end markdown
-
 =head1 AUTHOR
 
 Chisel <chisel@chizography.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Chisel Wright.
+This software is copyright (c) 2012 by Chisel Wright.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-__END__
-
-
 # vim: ts=8 sts=4 et sw=4 sr sta
